# Integrations

```{eval-rst}
.. module:: ehrdata
    :no-index:
```

## ML Frameworks

```{eval-rst}
.. autosummary::
    :toctree:
    :nosignatures:

    integrations.torch.OMOPEHRDataset

```

## Vitessce

```{eval-rst}
.. autosummary::
    :toctree:
    :nosignatures:

    integrations.vitessce.gen_config

```
